from django.apps import AppConfig


class ZapierTriggerConfig(AppConfig):

    name = "zapier.triggers"
    label = "zapier_triggers"
    verbose_name = "Zapier Triggers"
    default_auto_field = "django.db.models.BigAutoField"
